Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2402)

Unified Diff: chrome/browser/predictors/resource_prefetch_predictor.h

Issue 2227723002: predictors: Also track "no-cache" and "must-revalidate" resources. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/predictors/resource_prefetch_predictor.h
diff --git a/chrome/browser/predictors/resource_prefetch_predictor.h b/chrome/browser/predictors/resource_prefetch_predictor.h
index 15768ecf565f81f3dc87005b2053d29eea206b67..f03384513cdcffac8f21aa0f44de2dd6379ac385 100644
--- a/chrome/browser/predictors/resource_prefetch_predictor.h
+++ b/chrome/browser/predictors/resource_prefetch_predictor.h
@@ -187,8 +187,8 @@ class ResourcePrefetchPredictor
static bool IsHandledResourceType(content::ResourceType resource_type,
const std::string& mime_type);
- // Returns true if the request (should have a response in it) is cacheable.
- static bool IsCacheable(const net::URLRequest* request);
+ // Returns true if the request (should have a response in it) is "no-store".
+ static bool IsNoStore(const net::URLRequest* request);
// KeyedService methods override.
void Shutdown() override;

Powered by Google App Engine
This is Rietveld 408576698